@@ -33,79 +33,51 @@ pref("helpers.private_mailcap_file", "");
 pref("helpers.global_mime_types_file", "");
 pref("helpers.private_mime_types_file", "");
 
-// use google for keywords
+// enable keyword search
 pref("keyword.enabled", true);
 
 // disable usless security warnings
 pref("security.warn_entering_secure", false);
 pref("security.warn_entering_secure.show_once", true);
 pref("security.warn_leaving_secure", false);
+pref("security.warn_leaving_secure.show_once", false);
 pref("security.warn_submit_insecure", false);
 pref("security.warn_submit_insecure.show_once", false);
+pref("security.warn_viewing_mixed", true);
+pref("security.warn_viewing_mixed.show_once", false);
+pref("security.warn_entering_weak", true);
+pref("security.warn_entering_weak.show_once", false);
 
 // fonts
 pref("font.size.unit", "pt");
-pref("font.size.fixed.ar", 10);
-pref("font.size.fixed.x-baltic", 10);
-pref("font.size.fixed.x-central-euro", 10);
-pref("font.size.fixed.x-cyrillic", 10);
-pref("font.size.fixed.x-devanagari", 10);
-pref("font.size.fixed.el", 10);
-pref("font.size.fixed.he", 10);
-pref("font.size.fixed.ja", 10);
-pref("font.size.fixed.ko", 10);
-pref("font.size.fixed.zh-CN", 10);
-pref("font.size.fixed.x-tamil", 10);
-pref("font.size.fixed.th", 10);
-pref("font.size.fixed.zh-TW", 10);
-pref("font.size.fixed.zh-HK", 10);
-pref("font.size.fixed.tr", 10);
-pref("font.size.fixed.x-armn", 10);
-pref("font.size.fixed.x-beng", 10);
-pref("font.size.fixed.x-cans", 10);
-pref("font.size.fixed.x-ethi", 10);
-pref("font.size.fixed.x-geor", 10);
-pref("font.size.fixed.x-gujr", 10);
-pref("font.size.fixed.x-guru", 10);
-pref("font.size.fixed.x-khmr", 10);
-pref("font.size.fixed.x-mlym", 10);
-pref("font.size.fixed.x-unicode", 10);
-pref("font.size.fixed.x-western", 10);
-pref("font.size.variable.ar", 11);
-pref("font.size.variable.x-baltic", 11);
-pref("font.size.variable.x-central-euro", 11);
-pref("font.size.variable.x-cyrillic", 11);
-pref("font.size.variable.x-devanagari", 11);
-pref("font.size.variable.el", 11);
-pref("font.size.variable.he", 11);
-pref("font.size.variable.ja", 11);
-pref("font.size.variable.ko", 11);
-pref("font.size.variable.zh-CN", 11);
-pref("font.size.variable.x-tamil", 11);
-pref("font.size.variable.th", 11);
-pref("font.size.variable.zh-TW", 11);
-pref("font.size.variable.zh-HK", 11);
-pref("font.size.variable.tr", 11);
-pref("font.size.variable.x-armn", 11);
-pref("font.size.variable.x-beng", 11);
-pref("font.size.variable.x-cans", 11);
-pref("font.size.variable.x-ethi", 11);
-pref("font.size.variable.x-geor", 11);
-pref("font.size.variable.x-gujr", 11);
-pref("font.size.variable.x-guru", 11);
-pref("font.size.variable.x-khmr", 11);
-pref("font.size.variable.x-mlym", 11);
-pref("font.size.variable.x-unicode", 11);
-pref("font.size.variable.x-western", 11);
 
 // protocols
-pref("network.protocol-handler.external.news", true);
-pref("network.protocol-handler.external.mailto", true);
+pref("network.protocol-handler.external.ftp", false);
 pref("network.protocol-handler.external.irc", true);
+pref("network.protocol-handler.external.mailto", true);
+pref("network.protocol-handler.external.news", true);
+pref("network.protocol-handler.external.nntp", true);
+pref("network.protocol-handler.external.snews", true);
 pref("network.protocol-handler.external.webcal", true);
+// but don't show warnings for these
+pref("network.protocol-handler.warn-external.irc", false);
+pref("network.protocol-handler.warn-external.mailto", false);
+pref("network.protocol-handler.warn-external.news", false);
+pref("network.protocol-handler.warn-external.nntp", false);
+pref("network.protocol-handler.warn-external.snews", false);
+pref("network.protocol-handler.warn-external.webcal", false);
 
 // disable xpinstall
 pref("xpinstall.enabled", false);
 
 // enable typeahead find
 pref("accessibility.typeaheadfind", false);
+
+// disable pings
+pref("browser.send_pings", false);
+
+// disable blink tags
+pref("browser.blink_allowed", false);
+
+// enable spatial navigation (only works if the extension is built with gecko)
+pref("snav.enabled", true);
