@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.27 2006/02/02 22:25:18 chpe Exp $
+ *  $Id: GtkNSSClientAuthDialogs.cpp,v 1.27.2.2 2006/07/06 13:32:33 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,6 +26,7 @@
 
 #include "EphyUtils.h"
 #include "AutoJSContextStack.h"
+#include "AutoWindowModalState.h"
 
 #include <nsIDOMWindow.h>
 #include <nsIServiceManager.h>
@@ -151,9 +152,11 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 	rv = stack.Init ();
 	if (NS_FAILED (rv)) return rv;
 
-	nsCOMPtr<nsIDOMWindow> parent = do_GetInterface (ctx);
+	nsCOMPtr<nsIDOMWindow> parent (do_GetInterface (ctx));
 	GtkWindow *gparent = GTK_WINDOW (EphyUtils::FindGtkParent (parent));
 
+	AutoWindowModalState modalState (parent);
+
 	dialog = gtk_dialog_new_with_buttons ("",
 					      GTK_WINDOW (gparent),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -161,7 +164,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
 					      GTK_RESPONSE_CANCEL,
 					      _("_Select Certificate"),
 					      GTK_RESPONSE_OK,
-					      NULL);
+					      (char *) NULL);
 
 	if (gparent)
 	{
@@ -240,7 +243,7 @@ GtkNSSClientAuthDialogs::ChooseCertificate (nsIInterfaceRequestor *ctx,
         gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
         gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer,
                                         "text", 0,
-                                        NULL);
+                                        (char *) NULL);
 
 	gtk_widget_show (combo);
 	gtk_box_pack_start (GTK_BOX (vbox), combo, FALSE, TRUE, 0);
