@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.78.2.2 2006/04/03 11:58:15 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.78.2.4 2006/07/06 22:00:54 jframeau Exp $
  */
 
 #include "mozilla-config.h"
@@ -548,8 +548,7 @@ MozDownload::OnProgressChange (nsIWebProgress *aWebProgress,
 	PRInt64 now = PR_Now ();
 
 	if ((now - mLastUpdate < mInterval) &&
-	    (aMaxTotalProgress != -1) &&
-	    (aCurTotalProgress < aMaxTotalProgress))
+	    (aMaxTotalProgress == -1 || aCurTotalProgress < aMaxTotalProgress))
 		return NS_OK;
 
 	mLastUpdate = now;
@@ -607,7 +606,7 @@ MozDownload::GetInterface(const nsIID & uuid, void * *result)
 	{
 		EphyEmbedPersistFlags flags;
 
-		g_object_get (mEmbedPersist, "flags", &flags, NULL);
+		g_object_get (mEmbedPersist, "flags", &flags, (char *) NULL);
 
 		if (flags & EPHY_EMBED_PERSIST_NO_CERTDIALOGS)
 		{
@@ -782,12 +781,12 @@ GetFilePath (const char *filename)
 
 	if (ephy_ensure_dir_exists (download_dir, NULL))
 	{
-		path = g_build_filename (download_dir, filename, NULL);
+		path = g_build_filename (download_dir, filename, (char *) NULL);
 	}
 	else
 	{
 		home_dir = g_get_home_dir ();
-		path = g_build_filename (home_dir ? home_dir : "/", filename, NULL);
+		path = g_build_filename (home_dir ? home_dir : "/", filename, (char *) NULL);
 	}
 	g_free (download_dir);
 	
